<?php
$TRANSLATIONS = array(
"A safe home for all your data" => "Un spațiu de stocare sigur pentru toate datele tale",
"Access & share your files, calendars, contacts, mail & more from any device, on your terms" => "Accesează-ți și împărtășește-ți fișierele, calendarele, persoanele de contact, mesajele electronice și multe altele de pe orice dispozitiv, respectând termenii tăi",
"Get the apps to sync your files" => "Obține aplicația pentru sincronizarea fișierelor",
"Desktop client" => "Client desktop",
"Android app" => "Aplicație Android",
"iOS app" => "Aplicație iOS",
"Connect your desktop apps to %s" => "Conectează-ți aplicațiile desktop la %s",
"Connect your Calendar" => "Conectează-ți calendarul",
"Connect your Contacts" => "Conectează-ți contactele",
"Documentation" => "Documentație",
"Access files via WebDAV" => "Accesează fișierele prin WebDAV",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Găsești mai multe informații în <a target=\"_blank\" href=\"%s\">documentație</a> și pe <a target=\"_blank\" href=\"http://owncloud.org\">saitul nostru</a>."
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));";
